==> mastapy-14.0.0rc2-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/dynamics_response_3d_chart_type.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.system_model.analyses_and_results.modal_analyses import _4738
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_DynamicsResponse3DChartType")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_DynamicsResponse3DChartType",)


class EnumWithSelectedValue_DynamicsResponse3DChartType(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_DynamicsResponse3DChartType

    A specific implementation of 'EnumWithSelectedValue' for 'DynamicsResponse3DChartType' types.
    """

    __qualname__ = "DynamicsResponse3DChartType"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_DynamicsResponse3DChartType]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_DynamicsResponse3DChartType]",
    ) -> "_4738.DynamicsResponse3DChartType":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _4738.DynamicsResponse3DChartType
        """
        return _4738.DynamicsResponse3DChartType

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_DynamicsResponse3DChartType]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _4738.DynamicsResponse3DChartType.type_()

    @property
    def selected_value(self: "Self") -> "_4738.DynamicsResponse3DChartType":
        """mastapy._private.system_model.analyses_and_results.modal_analyses.DynamicsResponse3DChartType

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_4738.DynamicsResponse3DChartType]":
        """List[mastapy._private.system_model.analyses_and_results.modal_analyses.DynamicsResponse3DChartType]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.0.1b1-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/dynamics_response_3d_chart_type.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.system_model.analyses_and_results.modal_analyses import _4740

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_DynamicsResponse3DChartType")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_DynamicsResponse3DChartType",)


class EnumWithSelectedValue_DynamicsResponse3DChartType(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_DynamicsResponse3DChartType

    A specific implementation of 'EnumWithSelectedValue' for 'DynamicsResponse3DChartType' types.
    """

    __qualname__ = "DynamicsResponse3DChartType"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_DynamicsResponse3DChartType]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_DynamicsResponse3DChartType]",
    ) -> "_4740.DynamicsResponse3DChartType":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _4740.DynamicsResponse3DChartType
        """
        return _4740.DynamicsResponse3DChartType

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_DynamicsResponse3DChartType]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _4740.DynamicsResponse3DChartType.type_()

    @property
    def selected_value(self: "Self") -> "_4740.DynamicsResponse3DChartType":
        """mastapy.system_model.analyses_and_results.modal_analyses.DynamicsResponse3DChartType

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_4740.DynamicsResponse3DChartType]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses.DynamicsResponse3DChartType]

        Note:
            This property is readonly.
        """
        return None
